@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,10 +13,10 @@
 ##############################################################################
 """Test Login and Password
 
-$Id: test_loginpassword.py 106799 2009-12-20 04:50:49Z fafhrd $
+$Id$
 """
 import unittest
-from zope.testing import doctest
+import doctest
 
 def test_bbb_imports():
     """
